@@ -2,8 +2,8 @@ MBB_BASE_URL = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/
 MBB_TEAM_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/mbb/team_box/parquet/team_box_{season}.parquet'
 MBB_PLAYER_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/mbb/player_box/parquet/player_box_{season}.parquet'
 MBB_TEAM_LOGO_URL  = 'https://github.com/saiemgilani/hoopR-data/blob/master/mbb/teams_colors_logos.csv'
-MBB_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/mbb/schedules/parquet/schedules_{season}.parquet'
+MBB_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/mbb/schedules/parquet/mbb_schedule_{season}.parquet'
 NBA_BASE_URL = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/nba/pbp/parquet/play_by_play_{season}.parquet'
 NBA_TEAM_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/nba/team_box/parquet/team_box_{season}.parquet'
 NBA_PLAYER_BOX_URL  = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/nba/player_box/parquet/player_box_{season}.parquet'
-NBA_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/nba/schedules/parquet/schedules_{season}.parquet'
+NBA_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/hoopR-data/master/nba/schedules/parquet/nba_schedule_{season}.parquet'
