@@ -10,7 +10,7 @@ def load_mbb_pbp(seasons: List[int]) -> pd.DataFrame:
     """Load men's college basketball play by play data going back to 2002
 
     Example:
-        `mbb_df = hoopR.mbb.load_mbb_pbp(seasons=[range(2002,2022)])`
+        `mbb_df = hoopR.mbb.load_mbb_pbp(seasons=range(2002,2022))`
 
     Args:
         seasons (list): Used to define different seasons. 2002 is the earliest available season.
@@ -23,6 +23,8 @@ def load_mbb_pbp(seasons: List[int]) -> pd.DataFrame:
         ValueError: If `season` is less than 2002.
     """
     data = pd.DataFrame()
+    if type(seasons) is int:
+        seasons = [seasons]
     for i in seasons:
         if int(i) < 2002:
             raise SeasonNotFoundError("season cannot be less than 2002")
@@ -36,7 +38,7 @@ def load_mbb_team_boxscore(seasons: List[int]) -> pd.DataFrame:
     """Load men's college basketball team boxscore data
 
     Example:
-        `mbb_df = hoopR.mbb.load_mbb_team_boxscore(seasons=[range(2002,2022)])`
+        `mbb_df = hoopR.mbb.load_mbb_team_boxscore(seasons=range(2002,2022))`
 
     Args:
         seasons (list): Used to define different seasons. 2002 is the earliest available season.
@@ -49,6 +51,8 @@ def load_mbb_team_boxscore(seasons: List[int]) -> pd.DataFrame:
         ValueError: If `season` is less than 2002.
     """
     data = pd.DataFrame()
+    if type(seasons) is int:
+        seasons = [seasons]
     for i in seasons:
         if int(i) < 2002:
             raise SeasonNotFoundError("season cannot be less than 2002")
@@ -63,7 +67,7 @@ def load_mbb_player_boxscore(seasons: List[int]) -> pd.DataFrame:
     """Load men's college basketball player boxscore data
 
     Example:
-        `mbb_df = hoopR.mbb.load_mbb_player_boxscore(seasons=[range(2002,2022)])`
+        `mbb_df = hoopR.mbb.load_mbb_player_boxscore(seasons=range(2002,2022))`
 
     Args:
         seasons (list): Used to define different seasons. 2002 is the earliest available season.
@@ -76,6 +80,8 @@ def load_mbb_player_boxscore(seasons: List[int]) -> pd.DataFrame:
         ValueError: If `season` is less than 2002.
     """
     data = pd.DataFrame()
+    if type(seasons) is int:
+        seasons = [seasons]
     for i in seasons:
         if int(i) < 2002:
             raise SeasonNotFoundError("season cannot be less than 2002")
@@ -90,7 +96,7 @@ def load_mbb_schedule(seasons: List[int]) -> pd.DataFrame:
     """Load men's college basketball schedule data
 
     Example:
-        `mbb_df = hoopR.mbb.load_mbb_schedule(seasons=[range(2002,2022)])`
+        `mbb_df = hoopR.mbb.load_mbb_schedule(seasons=range(2002,2022))`
 
     Args:
         seasons (list): Used to define different seasons. 2002 is the earliest available season.
@@ -103,6 +109,8 @@ def load_mbb_schedule(seasons: List[int]) -> pd.DataFrame:
         ValueError: If `season` is less than 2002.
     """
     data = pd.DataFrame()
+    if type(seasons) is int:
+        seasons = [seasons]
     for i in seasons:
         if int(i) < 2002:
             raise SeasonNotFoundError("season cannot be less than 2002")
@@ -127,13 +135,33 @@ def mbb_calendar(season: int) -> pd.DataFrame:
     Raises:
         ValueError: If `season` is less than 2002.
     """
+    
+    if int(season) < 2002:
+        raise SeasonNotFoundError("season cannot be less than 2002")
     url = "http://site.api.espn.com/apis/site/v2/sports/basketball/mens-college-basketball/scoreboard?dates={}".format(season)
     resp = download(url=url)
     txt = json.loads(resp)['leagues'][0]['calendar']
-    reg = pd.DataFrame(txt[0]['entries'])
-    post = pd.DataFrame(txt[1]['entries'])
-    full_schedule = pd.concat([reg,post], ignore_index=True)
-    full_schedule['season']=season
-    return full_schedule
+    datenum = list(map(lambda x: x[:10].replace("-",""),txt))
+    date = list(map(lambda x: x[:10],txt))
+
+    year = list(map(lambda x: x[:4],txt))
+    month = list(map(lambda x: x[5:7],txt))
+    day = list(map(lambda x: x[8:10],txt))
+
+    data = {
+        "season": season,
+        "datetime" : txt,
+        "date" : date,
+        "year": year,
+        "month": month,
+        "day": day,
+        "dateURL": datenum
+    }
+    df = pd.DataFrame(data)
+    df['url']="http://site.api.espn.com/apis/site/v2/sports/basketball/mens-college-basketball/scoreboard?dates="
+    df['url']= df['url'] + df['dateURL']
+    return df
+
+
 
 
